nbgrader
========

``nbgrader`` is a tool that facilitates creating and grading assignments in the Jupyter notebook. It allows instructors to easily create notebook-based assignments that include both coding exercises and written free-responses. ``nbgrader`` then also provides a streamlined interface for quickly grading completed assignments.

.. toctree::
    :maxdepth: 1
    :caption: User Documentation

    user_guide/highlights
    Demo <https://github.com/jhamrick/nbgrader-demo>
    user_guide/installation
    user_guide/philosophy
    user_guide/creating_and_grading_assignments
    user_guide/managing_the_database
    user_guide/managing_assignment_files
    user_guide/autograding_resources
    user_guide/faq
    user_guide/advanced
    api/index

.. toctree::
    :maxdepth: 1
    :caption: Configuration

    configuration/student_version
    configuration/config_options
    command_line_tools/index
    configuration/jupyterhub_config
    plugins/index

.. toctree::
    :maxdepth: 1
    :caption: Developer Documentation

    contributor_guide/overview
    contributor_guide/installation_developer
    contributor_guide/metadata
    contributor_guide/pull_request
    contributor_guide/testing
    contributor_guide/documentation
    contributor_guide/js_dependencies
    contributor_guide/releasing

.. toctree::
    :maxdepth: 2
    :caption: Resources

    Source repository <https://github.com/jupyter/nbgrader>
    Jupyter education mailing list <http://tinyurl.com/jupyter-education>
    changelog
